use std::{fmt::Display, path::Path};

pub use ureq::http::{HeaderMap, StatusCode};

#[derive(Clone, Copy)]
pub enum Method {
    GET,
    HEAD,
    OPTIONS,
    TRACE,
    PUT,
    DELETE,
    POST,
    PATCH,
    CONNECT,
}

impl Display for Method {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        match self {
            Method::GET => write!(f, "get"),
            Method::HEAD => write!(f, "head"),
            Method::OPTIONS => write!(f, "options"),
            Method::TRACE => write!(f, "trace"),
            Method::PUT => write!(f, "put"),
            Method::DELETE => write!(f, "delete"),
            Method::POST => write!(f, "post"),
            Method::PATCH => write!(f, "patch"),
            Method::CONNECT => write!(f, "connect"),
        }
    }
}

pub struct Target<'a> {
    pub host: &'a str,
    pub path: &'a Path,
}

pub struct HttpSignature {
    pub signature: String,
    pub digest: String,
    pub date: String,
}
